==> sl2008_132_qt4win_src.zip: frmSkorloto.cpp <==
/* (C)opyright: Erdogan Tan  ( 29/9/2008 v1.3.1, 30/9/2008 v1.3.2 )
   SKORLOTO 417 6/49 Lotto Assistant Program (MS Windows & VB : 1996-2007)
   Originally, it was programmed with Visual Basic 3.0 and then VB 5.0, 6.0 & VB.NET
   Pardus/Linux QT4/C++ Version 1.3.2 Alpha [ 30-9-2008 Ascending Sort ]
  (Derivated from -Compatible with-  SKORLOTO 417 MS Windows Version 1.2, VB 5.0 Code)
*/

// Version 1.3.0 -> QT3/C++ 8/8/2007 

#include <QtGui> 
#include "frmSkorloto.h"

int ball(int);
int bag[50];
bool sbag[50];
// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
int num[7];
int sn[7];
void AscendingSort();

frmSkorloto::frmSkorloto(QWidget *parent) : QDialog (parent)
{
	setupUi(this);
	connect( cmdDraw, SIGNAL( clicked() ), this, SLOT( GetRandomBall() ) ); 
	connect( chkSort, SIGNAL( clicked() ), this, SLOT( ShowBalls() ) ); 
}
// 8/8/2007 v1.3.0 QT3/C++ , GetRandomBall
void frmSkorloto::GetRandomBall()
{
	ball(0);
	
	// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
	num[1]=ball(1);
	num[2]=ball(2);
	num[3]=ball(3);
	num[4]=ball(4);
	num[5]=ball(5);
	num[6]=ball(6);
	
	// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
	ShowBalls();
    
}

int ball(int r) {
     int x = 0;
     int n;
     
     if (r) {
	 int y = bag[(rand()%bag[0])+1];
	 sbag[y] = false;
	 bag[0] = 0;
	 for (n=1; n<50; n++) {
	       if (sbag[n] == true) { 
	            x += 1;
	            bag[x] = n;
	            bag[0] += 1;
	        }
	   }
              return y;
	  }
    else  { 
	sbag[0]=true;
	bag[0]=49;
	for (n=1; n<50; n++) {
        sbag[n]=true;  
	    bag[n] = n;
              }
             return 0;
    }
}

// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
void AscendingSort()
{
// Derivation from SKORLOTO 417 v2.2 PREMIUM, VB 5.0 Code (13-10-2002)
	int x;
	int y;
	int z;
	
	for (x=1; x<7; x++) {
		for (y=1; y<6; y++) {
			if (sn[y] > sn[y+1]) {
			   z = sn[y];
			   sn[y] = sn[y+1];
			   sn[y+1] = z;	
			}
		}
    }
}

// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
void frmSkorloto::ShowBalls()
{
	sn[1]=num[1];
	sn[2]=num[2];
	sn[3]=num[3];
	sn[4]=num[4];
	sn[5]=num[5];
	sn[6]=num[6];
	
	if ( chkSort->isChecked() == true ) {
		AscendingSort();
	}
// 8/8/2007 v1.3.0 QT3/C++ , GetRandomBalls
    textLabel1->setText(QString::number(sn[1],10));
    textLabel2->setText(QString::number(sn[2],10));
    textLabel3->setText(QString::number(sn[3],10));
    textLabel4->setText(QString::number(sn[4],10));
    textLabel5->setText(QString::number(sn[5],10));
    textLabel6->setText(QString::number(sn[6],10));
    
}

==> sl2008_133_qt4win_src.zip: frmSkorloto.cpp <==
/* (C)opyright: Erdogan Tan  ( 29/9/2008 v1.3.1, 30/9/2008 v1.3.2 )
   SKORLOTO 417 6/49 Lotto Assistant Program (MS Windows & VB : 1996-2007)
   Originally, it was programmed with Visual Basic 3.0 and then VB 5.0, 6.0 & VB.NET
   Pardus/Linux QT4/C++ Version 1.3.2 Alpha [ 30-9-2008 Ascending Sort ]
  (Derivated from -Compatible with-  SKORLOTO 417 MS Windows Version 1.2, VB 5.0 Code)
*/

// Version 1.3.0 -> QT3/C++ 8/8/2007 

#include <QtGui> 
#include <QTimer>
#include <QDateTime>
#include "frmSkorloto.h"

int ball(int);
int bag[50];
bool sbag[50];
// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
int num[7];
int sn[7];
void AscendingSort();
// 02/10/2008 v1.3.3 ( Date, Time )
// QString StrDateTime;
int saniye = 0;
bool FormClickState = false ;

frmSkorloto::frmSkorloto(QWidget *parent) : QDialog (parent)
{
	setupUi(this);
	QTimer *timer = new QTimer(this);
    connect(timer, SIGNAL(timeout()), this, SLOT( UpdateFormCaption() ) );
    timer->start(1000);
	connect( cmdDraw, SIGNAL( clicked() ), this, SLOT( GetRandomBall() ) ); 
	connect( chkSort, SIGNAL( clicked() ), this, SLOT( ShowBalls() ) ); 
}
// 8/8/2007 v1.3.0 QT3/C++ , GetRandomBall
void frmSkorloto::GetRandomBall()
{
	ball(0);
	
	// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
	num[1]=ball(1);
	num[2]=ball(2);
	num[3]=ball(3);
	num[4]=ball(4);
	num[5]=ball(5);
	num[6]=ball(6);
	
	// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
	ShowBalls();
    
}

int ball(int r) {
     int x = 0;
     int n;
     
     if (r) {
	 int y = bag[(rand()%bag[0])+1];
	 sbag[y] = false;
	 bag[0] = 0;
	 for (n=1; n<50; n++) {
	       if (sbag[n] == true) { 
	            x += 1;
	            bag[x] = n;
	            bag[0] += 1;
	        }
	   }
              return y;
	  }
    else  { 
	sbag[0]=true;
	bag[0]=49;
	for (n=1; n<50; n++) {
        sbag[n]=true;  
	    bag[n] = n;
              }
             return 0;
    }
}

// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
void AscendingSort()
{
// Derivation from SKORLOTO 417 v2.2 PREMIUM, VB 5.0 Code (13-10-2002)
	int x;
	int y;
	int z;
	
	for (x=1; x<7; x++) {
		for (y=1; y<6; y++) {
			if (sn[y] > sn[y+1]) {
			   z = sn[y];
			   sn[y] = sn[y+1];
			   sn[y+1] = z;	
			}
		}
    }
}

// 30/9/2008 v1.3.2 ( chkSort, AscendingSort, ShowBalls, num[], sn[] )
void frmSkorloto::ShowBalls()
{
	sn[1]=num[1];
	sn[2]=num[2];
	sn[3]=num[3];
	sn[4]=num[4];
	sn[5]=num[5];
	sn[6]=num[6];
	
	if ( chkSort->isChecked() == true ) {
		AscendingSort();
	}
// 8/8/2007 v1.3.0 QT3/C++ , GetRandomBalls
    textLabel1->setText(QString::number(sn[1],10));
    textLabel2->setText(QString::number(sn[2],10));
    textLabel3->setText(QString::number(sn[3],10));
    textLabel4->setText(QString::number(sn[4],10));
    textLabel5->setText(QString::number(sn[5],10));
    textLabel6->setText(QString::number(sn[6],10));
    
}

// 2/10/2008 v1.3.3 for Date & Time Display on Window Title
void frmSkorloto::UpdateFormCaption()
{
   	// QString DateTimeFormat = "dd.MM.yyyy hh:mm:ss";
	QDateTime DateTime = QDateTime::currentDateTime();
	QString StrDateTime = DateTime.toString ("dd.MM.yyyy hh:mm:ss");
	StrDateTime.prepend("SKORLOTO 417  ");
	frmSkorloto::setWindowTitle(StrDateTime);
}
